@@ -7,10 +7,11 @@ use Exporter   ();
 use File::Spec ();
 use Test::More ();
 
-our $VERSION = '1.44';
+our $VERSION = '1.54';
 our @ISA     = 'Exporter';
-our @EXPORT  = qw/connect_ok dies dbfile @CALL_FUNCS/;
+our @EXPORT  = qw/connect_ok dies dbfile @CALL_FUNCS $sqlite_call has_sqlite requires_sqlite/;
 our @CALL_FUNCS;
+our $sqlite_call;
 
 my $parent;
 my %dbfiles;
@@ -126,4 +127,57 @@ $DBI::VERSION >= 1.608 and push @CALL_FUNCS, sub {
   return $dbh->$method(@_);
 };
 
+
+=head2 $sqlite_call
+
+  $dbh->$sqlite_call(meth_name => @args);
+
+This is another way of testing driver-private methods, in a portable
+manner that works for DBI versions before or after 1.608. Unlike
+C<@CALL_FUNCS>, this does not require to loop -- because after all,
+it doesn't make much sense to test the old ->func() interface if
+we have support for the new ->sqlite_*() interface. With C<$sqlite_call>,
+the most appropriate API is chosen automatically and called only once.
+
+=cut
+
+$sqlite_call = sub {
+  my $dbh = shift;
+  my $func_to_call = shift;
+  $CALL_FUNCS[-1]->($dbh, @_, $func_to_call);
+};
+
+=head2 has_sqlite
+
+  has_sqlite('3.6.11');
+
+returns true if DBD::SQLite is built with a version of SQLite equal to or higher than the specified version.
+
+=cut
+
+sub has_sqlite {
+  my $version = shift;
+  my @version_parts = split /\./, $version;
+  my $format = '%d%03d%03d';
+  my $version_number = sprintf $format, @version_parts[0..2];
+  use DBD::SQLite;
+  return ($DBD::SQLite::sqlite_version_number && $DBD::SQLite::sqlite_version_number >= $version_number) ? 1 : 0;
+}
+
+=head2 requires_sqlite
+
+  BEGIN { requires_sqlite('3.6.11'); }
+
+skips all the tests if DBD::SQLite is not built with a version of SQLite equal to or higher than the specified version.
+
+=cut
+
+sub requires_sqlite {
+  my $version = shift;
+  unless (has_sqlite($version)) {
+    Test::More::plan skip_all => "this test requires SQLite $version and newer";
+    exit;
+  }
+}
+
 1;
